==> aws-cdk-lib-2.177.0-sources.jar: software/amazon/awscdk/services/lambda/AdotLambdaLayerJavaSdkVersion.java <==
package software.amazon.awscdk.services.lambda;

/**
 * The collection of versions of the ADOT Lambda Layer for Java SDK.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Function fn;
 * String layerArn = AdotLambdaLayerJavaSdkVersion.V1_19_0.layerArn(fn.getStack(), fn.getArchitecture());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.106.0 (build e852934)", date = "2025-01-25T00:20:57.775Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_lambda.AdotLambdaLayerJavaSdkVersion")
public class AdotLambdaLayerJavaSdkVersion extends software.amazon.jsii.JsiiObject {

    protected AdotLambdaLayerJavaSdkVersion(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AdotLambdaLayerJavaSdkVersion(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        LATEST = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "LATEST", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_19_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_19_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_28_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_28_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_30_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_30_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_31_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_31_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_32_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_32_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
    }

    /**
     * The ARN of the Lambda layer.
     * <p>
     * @param scope The binding scope. This parameter is required.
     * @param architecture The architecture of the Lambda layer (either X86_64 or ARM_64). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String layerArn(final @org.jetbrains.annotations.NotNull software.constructs.IConstruct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Architecture architecture) {
        return software.amazon.jsii.Kernel.call(this, "layerArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(architecture, "architecture is required") });
    }

    /**
     * The latest layer version available in this CDK version.
     * <p>
     * New versions could
     * introduce incompatible changes. Make sure to test them before deploying to production.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion LATEST;

    /**
     * Version 1.19.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_19_0;

    /**
     * Version 1.28.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_28_1;

    /**
     * Version 1.30.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_30_0;

    /**
     * Version 1.31.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_31_0;

    /**
     * Version 1.32.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_32_0;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.lang.String getLayerVersion() {
        return software.amazon.jsii.Kernel.get(this, "layerVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> aws-cdk-lib-2.178.1-sources.jar: software/amazon/awscdk/services/lambda/AdotLambdaLayerJavaSdkVersion.java <==
package software.amazon.awscdk.services.lambda;

/**
 * The collection of versions of the ADOT Lambda Layer for Java SDK.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Function fn;
 * String layerArn = AdotLambdaLayerJavaSdkVersion.V1_19_0.layerArn(fn.getStack(), fn.getArchitecture());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.106.0 (build e852934)", date = "2025-02-06T22:15:56.636Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_lambda.AdotLambdaLayerJavaSdkVersion")
public class AdotLambdaLayerJavaSdkVersion extends software.amazon.jsii.JsiiObject {

    protected AdotLambdaLayerJavaSdkVersion(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AdotLambdaLayerJavaSdkVersion(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        LATEST = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "LATEST", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_19_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_19_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_28_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_28_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_30_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_30_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_31_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_31_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_32_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_32_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
        V1_32_0_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class, "V1_32_0_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion.class));
    }

    /**
     * The ARN of the Lambda layer.
     * <p>
     * @param scope The binding scope. This parameter is required.
     * @param architecture The architecture of the Lambda layer (either X86_64 or ARM_64). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String layerArn(final @org.jetbrains.annotations.NotNull software.constructs.IConstruct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Architecture architecture) {
        return software.amazon.jsii.Kernel.call(this, "layerArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(architecture, "architecture is required") });
    }

    /**
     * The latest layer version available in this CDK version.
     * <p>
     * New versions could
     * introduce incompatible changes. Make sure to test them before deploying to production.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion LATEST;

    /**
     * Version 1.19.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_19_0;

    /**
     * Version 1.28.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_28_1;

    /**
     * Version 1.30.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_30_0;

    /**
     * Version 1.31.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_31_0;

    /**
     * Version 1.32.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_32_0;

    /**
     * Version 1.32.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.lambda.AdotLambdaLayerJavaSdkVersion V1_32_0_1;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.lang.String getLayerVersion() {
        return software.amazon.jsii.Kernel.get(this, "layerVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
